| estimate.amplitude | R Documentation |
Estimates Amplitude of Signal as Max value
estimate.amplitude(averaged_signal)
averaged_signal |
Averaged Signal for function to be performed on |
|
Maximum value of data serving as estimate for peak amplitude |
#mysignal<-noise(200,10,250)+peak(200,10,250,7,115)
#mysignal<-signal.averaging(mysignal,200,10)
#estimate.amplitude(mysignal)
## The function is currently defined as
estimate.amplitude<-function(averaged_signal){
return(max(averaged_signal))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.